==> sqlfluff-1.3.0-1-any.pkg.tar.zst: usr/lib/python3.10/site-packages/sqlfluff/dialects/dialect_bigquery_keywords.py <==
"""A list of all BigQuery SQL key words."""

# https://cloud.google.com/bigquery/docs/reference/standard-sql/lexical#reserved_keywords
bigquery_reserved_keywords = """ALL
AND
ANY
ARRAY
AS
ASC
ASSERT_ROWS_MODIFIED
AT
BETWEEN
BY
CASE
CAST
COLLATE
CONTAINS
CREATE
CROSS
CUBE
CURRENT
DEFAULT
DEFINE
DESC
DISTINCT
ELSE
END
ENUM
ESCAPE
EXCEPT
EXCLUDE
EXISTS
FALSE
FETCH
FOLLOWING
FOR
FROM
FULL
GROUP
GROUPING
GROUPS
HASH
HAVING
IF
IGNORE
IN
INCLUDE
INNER
INTERSECT
INTERVAL
INTO
IS
JOIN
LATERAL
LEFT
LIKE
LIMIT
LOOKUP
MERGE
NEW
NO
NOT
NULL
NULLS
OF
ON
OR
ORDER
OUTER
OVER
PARTITION
PIVOT
PRECEDING
PROTO
RANGE
RECURSIVE
RESPECT
RIGHT
ROLLUP
ROWS
SELECT
SET
SOME
STRUCT
TABLESAMPLE
THEN
TO
TREAT
TRUE
UNBOUNDED
UNION
UNNEST
UNPIVOT
USING
WHEN
WHERE
WINDOW
WITH
WITHIN"""

# Note BigQuery doesn't have a list of Unreserved Keywords
# so these are just ones we need to allow parsing to work
bigquery_unreserved_keywords = """ACCOUNT
ADD
ADMIN
AFTER
ALTER
APPLY
ASSERT
AUTO_INCREMENT
BEGIN
BERNOULLI
BINARY
BINDING
BREAK
CACHE
CALL
CASCADE
CHAIN
CHARACTER
CHECK
CLUSTER
COLUMN
COLUMNS
COMMENT
COMMIT
CONCURRENTLY
CONTINUE
CONNECT
CONNECTION
CONSTRAINT
COPY
CURRENT_USER
CYCLE
DATA
DATABASE
DATE
DATETIME
DECLARE
DELETE
DESCRIBE
DETERMINISTIC
DO
DOMAIN
DOUBLE
DROP
ELSEIF
EXECUTE
EXECUTION
EXPLAIN
EXPORT
EXTENSION
EXTERNAL
FILE
FILTER
FIRST
FOREIGN
FORMAT
FUNCTION
FUTURE
GRANT
GRANTED
GRANTS
HOUR
ILIKE
IMPORTED
IN
INCREMENT
INDEX
INOUT
INSERT
INTEGRATION
ITERATE
LANGUAGE
LARGE
LAST
LEAVE
LOOP
MANAGE
MASKING
MATCHED
MATERIALIZED
MAXVALUE
MESSAGE
MINUS
MINVALUE
ML
MODEL
MODIFY
MONITOR
NAME
NAN
NFC
NFKC
NFD
NFKD
NOCACHE
NOCYCLE
NOORDER
OBJECT
OFFSET
OPERATE
OPTION
OPTIONS
ORDINAL
OUT
OVERLAPS
OVERWRITE
OWNERSHIP
PERCENT
PIPE
POLICY
PRECISION
PRIMARY
PRIOR
PRIVILEGES
PROCEDURE
PUBLIC
QUALIFY
QUARTER
RAISE
READ
REFERENCE_USAGE
REFERENCES
RENAME
REPEAT
REPEATABLE
REPLACE
RESOURCE
RESTRICT
RETURN
RETURNS
REVOKE
RLIKE
ROLE
ROLLBACK
ROW
ROUTINE
SAFE
SCHEMA
SCHEMAS
SECOND
SEPARATOR
SERVER
SEQUENCE
SESSION_USER
SHARE
SOURCE
STAGE
START
STREAM
SYSTEM
SYSTEM_TIME
TABLE
TABLESPACE
TARGET
TASK
TEMP
TEMPORARY
TIME
TIMESTAMP
TRANSACTION
TRANSIENT
TRIGGER
TRUNCATE
TYPE
UNIQUE
UNSIGNED
UNTIL
UPDATE
USAGE
USE
USE_ANY_ROLE
USER
VALUE
VALUES
VARYING
VERSION
VIEW
WAREHOUSE
WHILE
WITHOUT
WORK
WRAPPER
WRITE
ZONE"""

==> sqlfluff-3.4.1-1-any.pkg.tar.zst: usr/lib/python3.13/site-packages/sqlfluff/dialects/dialect_bigquery_keywords.py <==
"""A list of all BigQuery SQL key words."""

# https://cloud.google.com/bigquery/docs/reference/standard-sql/lexical#reserved_keywords
bigquery_reserved_keywords = """AGGREGATE
ALL
AND
ANY
ARRAY
AS
ASC
ASSERT_ROWS_MODIFIED
AT
BETWEEN
BY
CASE
CAST
CLONE
COLLATE
CONTAINS
CORRESPONDING
CREATE
CROSS
CUBE
CURRENT
DEFAULT
DEFINE
DESC
DISTINCT
ELSE
END
ENUM
ESCAPE
EXCEPT
EXCLUDE
EXISTS
EXTEND
FALSE
FETCH
FOLLOWING
FOR
FROM
FULL
GROUP
GROUPING
GROUPS
HASH
HAVING
IF
IGNORE
IN
INCLUDE
INNER
INTERSECT
INTERVAL
INTO
IS
JOIN
LATERAL
LEFT
LIKE
LIMIT
LOOKUP
MERGE
NEW
NO
NOT
NULL
NULLS
OF
ON
OR
ORDER
OUTER
OVER
PARTITION
PIVOT
PRECEDING
PRIMARY
PROTO
RANGE
RECURSIVE
RESPECT
RIGHT
ROLLUP
ROWS
SELECT
SET
SOME
STRUCT
TABLESAMPLE
THEN
TO
TREAT
TRUE
UNBOUNDED
UNION
UNNEST
UNPIVOT
USING
WHEN
WHERE
WINDOW
WITH
WITHIN"""

# Note BigQuery doesn't have a list of Unreserved Keywords
# so these are just ones we need to allow parsing to work
bigquery_unreserved_keywords = """ACCESS
ACCOUNT
ADD
ADMIN
AFTER
ALTER
APPLY
ASSIGNMENT
ASSERT
AUTO_INCREMENT
BEGIN
BERNOULLI
BI_CAPACITY
BINARY
BINDING
BREAK
CACHE
CALL
CAPACITY
CASCADE
CHAIN
CHARACTER
CHECK
CLONE
CLUSTER
COLUMN
COLUMNS
COMMENT
COMMIT
CONCURRENTLY
CONTINUE
CONNECT
CONNECTION
CONSTRAINT
COPY
CURRENT_USER
CYCLE
DATA
DATABASE
DATE
DATETIME
DECLARE
DELETE
DESCRIBE
DETERMINISTIC
DO
DOMAIN
DOUBLE
DROP
ELSEIF
ENFORCED
ERROR
EXCEPTION
EXECUTE
EXECUTION
EXPLAIN
EXPORT
EXTENSION
EXTERNAL
FILE
FILES
FILTER
FIRST
FOREIGN
FORMAT
FRIDAY
FUNCTION
FUTURE
GRANT
GRANTED
GRANTS
HOUR
ILIKE
IMMEDIATE
IMPORTED
IN
INCREMENT
INDEX
INOUT
INSERT
INTEGRATION
KEY
ITERATE
LANGUAGE
LARGE
LAST
LEAVE
LOAD
LOOP
MANAGE
MASKING
MATCHED
MATERIALIZED
MAX
MAXVALUE
MESSAGE
MIN
MINUS
MINVALUE
ML
MODEL
MODIFY
MONDAY
MONITOR
NAME
NAN
NFC
NFKC
NFD
NFKD
NOCACHE
NOCYCLE
NOORDER
OBJECT
OFFSET
OPERATE
OPTION
OPTIONS
ORDINAL
ORGANIZATION
OUT
OVERLAPS
OVERWRITE
OWNERSHIP
PARTITIONS
PERCENT
PIPE
POLICY
PRECISION
PRIMARY
PRIOR
PRIVILEGES
PROCEDURE
PROJECT
PUBLIC
QUALIFY
QUARTER
RAISE
READ
REFERENCE_USAGE
REFERENCES
RENAME
REPEAT
REPEATABLE
REPLACE
REPLICA
RESERVATION
RESOURCE
RESTRICT
RETURN
RETURNS
REVOKE
RLIKE
ROLE
ROLLBACK
ROW
ROUTINE
SAFE
SATURDAY
SCHEMA
SCHEMAS
SEARCH
SECOND
SEPARATOR
SERVER
SEQUENCE
SESSION_USER
SETS
SHARE
SNAPSHOT
SOURCE
STAGE
START
STREAM
STRICT
SUNDAY
SYSTEM
SYSTEM_TIME
TABLE
TABLESPACE
TARGET
TASK
TEMP
TEMPORARY
THURSDAY
TIME
TIMESTAMP
TRANSACTION
TRANSIENT
TRIGGER
TRUNCATE
TUESDAY
TYPE
UNDROP
UNIQUE
UNSIGNED
UNTIL
UPDATE
USAGE
USE
USE_ANY_ROLE
USER
VALUE
VALUES
VARYING
VECTOR
VERSION
VIEW
WAREHOUSE
WEDNESDAY
WEEK
WHILE
WITHOUT
WORK
WRAPPER
WRITE
ZONE"""
